# Import Widgets
from tkinter import BOTH , NO
import ttkbootstrap as ttk
from kanwar import MessageBox
from kanwar import envVars as myEnv

class Session:
    def __init__(self,grandMaster,master):
        self.grandMaster = grandMaster
        self.master = master
        self.root = ttk.LabelFrame(self.master , text = 'Sessions')
        self.root.pack(fill = BOTH, expand=1)

        self.leftColumn = ttk.Frame(self.root)
        self.leftColumn.pack(expand=1,fill = BOTH,padx=10)

        #### Row 1

        self.scrollx = ttk.Scrollbar(self.leftColumn , orient='horizontal')
        self.scrolly = ttk.Scrollbar(self.leftColumn , orient='vertical')
        self.scrolly.pack(side = 'right',fill='y')
        self.scrollx.pack(side = 'bottom',fill='x')

        self.columns = ('sr', 'email' , 'pass' , 'role' , 'date' , 'time' , 'rem') 

        self.tree = ttk.Treeview(self.leftColumn , columns=self.columns,
                        xscrollcommand=self.scrollx.set,yscrollcommand=self.scrolly.set)
        self.tree.pack(fill=BOTH,expand=1)

        self.scrollx.config(command=self.tree.xview)
        self.scrolly.config(command=self.tree.yview)

        self.tree.column("#0" , width = 0 , stretch=NO)

        self.tree.heading("sr" , text = 'Sr.' , anchor='w')
        self.tree.heading("email" , text = 'Email' , anchor='w')
        self.tree.heading("pass" , text = 'Password' , anchor='w')
        self.tree.heading("role" , text = 'Role',anchor='w')
        self.tree.heading("date" , text = 'Date' , anchor='w')
        self.tree.heading("time" , text = 'Time' , anchor='w')
        self.tree.heading("rem" , text = 'Keep Logged In' , anchor='w')

        self.tree.column('sr' , width=200 , anchor='w')
        self.tree.column('email' , width=200 , anchor='w')
        self.tree.column('pass' , width=200 , anchor='w')
        self.tree.column('role' , width=200 , anchor='w')
        self.tree.column('date' , width=200 , anchor='w')
        self.tree.column('time' , width=200 , anchor='w')
        self.tree.column('rem' , width=200 , anchor='w')
        self.tree["displaycolumns"]=('sr', 'email' , 'role' , 'date' , 'time' , 'rem') 
        self.show_sessions()
    ####################################### FUNCTIONS ##############################################
    def show_sessions(self,event=None):
        pass
if __name__ == "__main__":
    root = ttk.Window('Kanwar Adnan','united')
    frame = Frame(root)
    frame.pack()
    sessionTab = Session(root,frame)
    root.mainloop()



# Import Widgets
from tkinter import BOTH , NO , StringVar 
import ttkbootstrap as ttk
from kanwar import MessageBox
from tkinter import filedialog
from kanwar import envVars as myEnv

class Student:
    def __init__(self,grandMaster,master):
        self.grandMaster = grandMaster
        self.master = master
        self.dname = StringVar()
        self.drollno = StringVar()
        self.classes = []
        self.columns = ('Sr','code','roll no','name') 

        self.root = ttk.LabelFrame(self.master , text='Student Managment')
        self.root.pack(expand=1, fill=BOTH)
        self.left_column = ttk.Frame(self.root)
        self.left_column.pack(expand=1,fill = BOTH)

        #### Row 1

        self.row1 = ttk.Frame(self.left_column)
        self.row1.pack(side = 'top' , fill = 'x', padx = 10 , pady = 10)

        self.lbl_course_code = ttk.Label(self.row1 , text='Class Code :   ')
        self.lbl_course_code.pack(side = 'left' , padx = 10)

        self.com_codes = ()

        self.com_course_code = ttk.Combobox(self.row1 , state='readonly' , values=self.com_codes , width=18)
        self.com_course_code.pack(side = 'left' , padx = 18)

        #### Row 1.1

        self.row1_1 = ttk.Frame(self.left_column)
        self.row1_1.pack(side = 'top' , fill = 'x', padx = 10 , pady = 10)

        self.lbl_rollno = ttk.Label(self.row1_1 , text = 'Roll No : ')
        self.lbl_rollno.pack(side = 'left' , padx = 11)

        self.txt_rollno = ttk.Entry(self.row1_1 , textvariable=self.drollno)
        self.txt_rollno.pack(side ='left' , padx = [42,10])

        self.lbl_student_name = ttk.Label(self.row1_1,text = 'Student Name : ')
        self.lbl_student_name.pack(side = 'left' , padx = 10)

        self.txt_student_name = ttk.Entry(self.row1_1 , textvariable=self.dname , width = 45)
        self.txt_student_name.pack(side = 'left' , padx = 10)

        #### Row 2
        self.row2 = ttk.Frame(self.left_column)
        self.row2.pack(fill = 'both' , padx = 10 , pady = 10, expand=1)

        self.scrollx = ttk.Scrollbar(self.row2 , orient='horizontal')
        self.scrolly = ttk.Scrollbar(self.row2 , orient='vertical')
        self.scrolly.pack(side = 'right',fill='y')
        self.scrollx.pack(side = 'bottom',fill='x')

        self.tree = ttk.Treeview(self.row2 , columns=self.columns,
                        xscrollcommand=self.scrollx.set,yscrollcommand=self.scrolly.set)
        self.tree.pack(fill=BOTH,expand=1)

        self.scrollx.config(command=self.tree.xview)
        self.scrolly.config(command=self.tree.yview)

        self.tree.column("#0" , width = 0 , stretch=NO)

        self.tree.heading("Sr" , text = 'Sr.' , anchor='w')
        self.tree.heading("code" , text = 'Code' , anchor='w')
        self.tree.heading("roll no" , text = 'Name',anchor='w')
        self.tree.heading("name" , text = 'Roll No.' , anchor='w')

        self.tree.column('Sr' , width=200 , anchor='w')
        self.tree.column('code' , width=200 , anchor='w')
        self.tree.column('roll no' , width=200 , anchor='w')
        self.tree.column('name' , width=200 , anchor='w')

        #### Row 3
        ######## BUTTONS 

        self.row3 = ttk.Frame(self.left_column)
        self.row3.pack(fill = 'x' , padx = [0,0] , pady = 10)

        self.btn_add = ttk.Button(self.row3, text = 'Save' , width = 12 , command = self.add_student)
        self.btn_add.pack(side = 'left' , padx = 10)

        self.btn_clear = ttk.Button(self.row3 , text = 'Reset' , width = 12 , command = self.reset_student)
        self.btn_clear.pack(side = 'left' , padx  = 10)

        self.btn_update = ttk.Button(self.row3 , text = 'Update' , width = 12 , command = self.update_student)
        self.btn_update.pack(side = 'left' , padx = 10)

        self.btn_delete = ttk.Button(self.row3 , text = 'Delete' , width = 12 , command = self.delete_student)
        self.btn_delete.pack(side = 'left' , padx = 10)

        self.btn_sort = ttk.Button(self.row3 , text = 'Sort' , width = 12 , command = self.sort_student)
        self.btn_sort.pack(side = 'left' , padx  = 10)

        self.btn_export = ttk.Button(self.row3 , text = 'Export' , width = 12 , command = self.export_student)
        self.btn_export.pack(side = 'left' , padx = 10)

        self.txt_search = ttk.Entry(self.row3)
        self.txt_search.pack(padx=10,side='left',fill='x',expand=1)

        self.txt_search.bind("<KeyPress>",self.search_student)

        self.btn_delete.configure(state='disabled')
        self.btn_update.configure(state='disabled')
        self.btn_sort.configure(state='disabled')

        self.com_course_code.bind("<<ComboboxSelected>>",lambda e, : self.btn_sort.configure(state='active'))
        self.tree.bind("<ButtonRelease-1>",self.getdata_student)
        self.show_class()
        self.show_student()
    ####################################### DATA BASE START ##########################################

    def show_student(self,event=None):
        pass

    def show_student2(self,event=None):
        pass

    def sort_student(self,event=None):
        pass

    def export_student(self,event=None):
        pass

    ###############################################################################################
    def getdata_student(self,event=None):
        pass

    def reset_student(self,event=None):
        pass

    def search_student(self,event=None):
        pass

    def delete_student(self,event=None):
        pass

    def update_student(self,event=None):
        pass

    def add_student(self,event=None):
        pass

    def show_class(self,event=None):
        pass

    ####################################### DATA BASE END ##########################################


if __name__ == "__main__":
    root = ttk.Window('Kanwar Adnan','united')
    app = Student(root,ttk.Frame(root).pack())
    root.focus_set()
    root.mainloop()




from tkinter import BOTH , N , E , W , S , CENTER , LEFT , Canvas , Label
from tkinter import ttk
from ttkbootstrap import Style

class MyFrame(ttk.Frame):
    vals = ['Present','Absent','Leave']
    def __init__ (self,root,window,*args,**kwargs):
        self.root = root
        self.window = window
        self.data = []
        self.boxes = []
        self.padx = 10

        self.col_0 = [] # Labels
        self.col_1 = [] # Labels
        self.col_2 = [] # Labels

        self.pady = 10

        self.main_frame = ttk.Frame(self.root)
        self.main_frame.pack(expand=1,fill=BOTH)

        self.right_frame = ttk.Frame(self.main_frame)
        self.right_frame.pack(side = 'right' , fill = 'y')

        self.mid_frame = ttk.Frame(self.main_frame)
        self.mid_frame.pack(expand=1 , fill = 'both')

        self.bottom_frame = ttk.Frame(self.main_frame)
        self.bottom_frame.pack(side = 'bottom' , fill = 'x')

        self.scrollx = ttk.Scrollbar(self.bottom_frame,orient='horizontal')

        self.scrolly = ttk.Scrollbar(self.right_frame,orient='vertical')
        self.scrolly.pack(side = 'right' , fill = 'y')
        self.scrollx.pack(side = 'bottom' , fill = 'x')

        self.canvas = Canvas(self.mid_frame,yscrollcommand=self.scrolly.set,xscrollcommand=self.scrollx.set, highlightthickness=0, relief='flat' , border=0)
        self.canvas.pack(expand=True,fill=BOTH , side=LEFT)

        self.scrolly.config(command=self.canvas.yview)
        self.canvas.bind('<Configure>', lambda e: self.canvas.configure(scrollregion = self.canvas.bbox("all")))
        self.scrollx.config(command=self.canvas.xview)

        ttk.Frame.__init__(self,self.canvas,*args,**kwargs)
        self.pack(expand=1,fill=BOTH)

        self.canvas.create_window((0,0),window=self,anchor='nw')

        self.bind("<Enter>", self.entered)
        self.bind("<Leave>", self.left)

    def _on_mouse_wheel(self,event):
        self.canvas.update_idletasks()
        self.canvas.yview_scroll(-1 * int((event.delta / 60)), "units")

    def entered(self,event):
        self.canvas.bind_all("<MouseWheel>", self._on_mouse_wheel)
        self.canvas.bind("<1>",     lambda event: self.canvas.focus_set())
        self.canvas.bind("<Up>",    lambda event: self.canvas.yview_scroll(-5, "units"))
        self.canvas.bind("<Down>",  lambda event: self.canvas.yview_scroll( 5, "units"))
        self.canvas.bind("<Left>",    lambda event: self.canvas.xview_scroll(-5, "units"))
        self.canvas.bind("<Right>",  lambda event: self.canvas.xview_scroll( 5, "units"))

#        self.canvas.focus_set()
        
    def left(self,event):
        self.canvas.unbind_all("<MouseWheel>")
        self.canvas.unbind("<1>")
        self.canvas.unbind("<Up>")
        self.canvas.unbind("<Down>")
        self.canvas.unbind("<Left>")
        self.canvas.unbind("<Right>")

    def even_odd(self,data,order=None):
        if order=='even':
            return [j for i,j in enumerate(data) if i%2==0]
        elif order=='odd':
            return [j for i,j in enumerate(data) if i%2!=0]
        else:
            return data

    def make_rows(self,data,order=None):
        self.data = data.copy()
        data = self.even_odd(data,order=order)
        self.add_data(data)

    def add_data(self,data):
        column = 0
        prime_index = 0
        font =  ('Helvetica',12)
        self.Label = Label(self , text= 'Sr # ' , font=("Helvetica",12,'bold'))
        self.Label.grid(row = 0 , column=0)

        self.Label = Label(self , text= 'Name ' , font=("Helvetica",12,'bold'))
        self.Label.grid(row = 0 , column=1 , sticky=W)

        self.Label = Label(self, text= 'Roll No. ' , font=("Helvetica",12,'bold'))
        self.Label.grid(row = 0 , column=2)

        #self.Label = Label(self , text= 'Status ' , font=("Helvetica",12,'bold'))
        #self.Label.grid(row = 0 , column=3 , sticky=W)

        self.com_mode = ttk.Combobox(self, state='readonly',values=MyFrame.vals , width=10)
        self.com_mode.grid(row = 0 , column = 3 , sticky=W , pady=10)
        self.com_mode.current(0)

        self.com_mode.bind("<<ComboboxSelected>>",self.assign)

        for index in range(len(data)):
            prime_index += 1
            val = Label(self , text=prime_index , font=font)
            val.grid(row = index+1 , column=0 , pady = self.pady)
            self.col_0.append(val)

            for col,value in enumerate(data[index]):
                if col == 1:
                    val = Label(self,text=value,anchor=CENTER,justify='left',font=font)
                    val.grid(row=index+1,column=col+1 , sticky='ns')
                else:
                    val = Label(self,text=value.upper(),anchor='w',justify='left',font=font)
                    val.grid(row=index+1,column=col+1 , sticky=W)
                if col == 0:
                    self.col_1.append(val)
                elif col == 1:
                    self.col_2.append(val)

                column = col+1

            self.grid_columnconfigure([i for i in range(len(data[index])+2)], weight=1,uniform="column",pad=self.padx)

            comb = ttk.Combobox(self ,state='readonly', values=MyFrame.vals , width=10 , justify='left')
            comb.current(0)
            comb.grid(row=index+1,column=column+1 , pady = self.pady , sticky=W)
            comb.bind("<Tab>",lambda e : self.next(e))
            comb.bind("<Shift-Tab>",lambda e : self.prev(e))

            self.boxes.append(comb)

    def assign(self,event=None):
        info = self.Status_boxes()
        for i in info:
            i.set(self.com_mode.get())

    def prev(self,event=None):
        self.canvas.yview_scroll(-1,'units')
        event.widget.tk_focusPrev.focus()

    def next(self,event=None):
        self.canvas.yview_scroll(1, "units")
        event.widget.tk_focusNext().focus()

    def Status_boxes(self,event=None):
        return self.boxes.copy()

    def Data(self,event=None):
        return self.data.copy()

    def Boxes(self):
        return [i.get() for i in self.boxes.copy()]

    def add_item(self,data,item):
        li = []
        li.clear()
        for j,i in enumerate(data):
            i.append(item[j])
            li.append(i)
        return li

    def returninfo(self,event=None):
        info = self.data.copy()
        vals = self.boxes.copy()
        #remainder = self.add_item(info,vals)
        return None

if __name__ == '__main__':
    root = Style(theme='united')
    root = root.master
    root.geometry('900x600+0+0')
    root.title("Kanwar Adnan")
    f2 = ttk.Frame(root)
    f2.pack(fill=BOTH,expand=1)
    f1 = MyFrame(f2,root)

    #data = [(str(i),str(i**2)) for i in range(101)]
    data = [
            ['Made by Kanwar Adnan','1'],
            ['kanwaradnanrajput@gmail.com','2']
            ]
    f1.make_rows(data*10)
    f3 = ttk.Frame(root)
    f3.pack(side ='bottom' , fill='x')

    def add_item(data,item):
        a = list(zip(data,item))

    a = f1.Data()
    b = f1.Boxes()
    add_item(a,b)
    root.mainloop()


# Import Widgets
# This tab needs construction
from tkinter import * 
import ttkbootstrap as ttk
from kanwar import MessageBox
from kanwar import envVars as myEnv

class Report:
    def __init__(self,grandMaster,master):
        self.grandMaster = grandMaster
        self.master = master
        self.classes = []
        self.rollnumbers = []
        self.dates = []

        self.root = ttk.LabelFrame(self.master  , text ='Report')
        self.root.pack(expand=1,fill='both')

        self.leftColumn = ttk.Frame(self.root)
        self.leftColumn.pack(expand=1,fill='both')

        self.leftColumn_row1 = ttk.Frame(self.leftColumn)
        self.leftColumn_row1.pack(side='top',fill='x',padx=10)

        self.lbl_class_report = ttk.Label(self.leftColumn_row1 , text='Class Code :')
        self.lbl_class_report.grid(row=0,column=0)

        self.com_class_report = ttk.Combobox(self.leftColumn_row1,state='readonly',values=self.classes , width=18)
        self.com_class_report.grid(row=0,column=1,pady=10 , sticky='ew')

        self.lbl_rollno_report = ttk.Label(self.leftColumn_row1 , text='Roll No :')
        self.lbl_rollno_report.grid(row=0,column=2)

        self.com_rollno_report = ttk.Combobox(self.leftColumn_row1,values=[],state='readonly' , width=18) # rollnumbers
        self.com_rollno_report.grid(row=0,column=3,pady=10 , sticky='ew')

        self.lbl_lecture_report = ttk.Label(self.leftColumn_row1 , text='Lecture :')
        self.lbl_lecture_report.grid(row=0,column=4)

        self.com_lecture_report = ttk.Combobox(self.leftColumn_row1,values=() , width=18,state='readonly')
        self.com_lecture_report.grid(row=0,column=5,pady=10 , sticky='ew')

        self.lbl_month_report = ttk.Label(self.leftColumn_row1 , text='Month :  ')
        self.lbl_month_report.grid(row=1,column=0)

        self.com_month_report = ttk.Combobox(self.leftColumn_row1,values=() , width=18,state='readonly')
        self.com_month_report.grid(row=1,column=1,pady=10 , sticky='ew')

        self.leftColumn_row1.columnconfigure((0,1,2,3,4,5),weight=1)

        self.com_class_report.bind("<<ComboboxSelected>>",self.get_rollnumbers_report)
        self.com_month_report.bind("<<ComboboxSelected>>",self.get_details)
        ###################################################
        self.leftColumn_row2 = ttk.Frame(self.leftColumn)
        self.leftColumn_row2.pack(expand=1,fill = BOTH,pady=10,padx=10)

        #### Row 1

        self.scrollx = ttk.Scrollbar(self.leftColumn_row2 , orient='horizontal')
        self.scrolly = ttk.Scrollbar(self.leftColumn_row2 , orient='vertical')
        self.scrolly.pack(side = 'right',fill='y')
        self.scrollx.pack(side = 'bottom',fill='x')

        self.class_columns_page8 = ('sr' ,'lecture','a','b','c','d','e','f','g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v','w','x','y','z','aa','ab','ac','ad') 

        self.tree = ttk.Treeview(self.leftColumn_row2 , columns=self.class_columns_page8,
                        xscrollcommand=self.scrollx.set,yscrollcommand=self.scrolly.set)
        self.tree.pack(fill='both',expand=1)

        self.scrollx.config(command=self.tree.xview)
        self.scrolly.config(command=self.tree.yview)

        self.tree.column("#0" , width = 0 , stretch=NO)

        self.tree.heading("sr" , text = 'Sr.' , anchor='w')
        self.tree.heading("lecture" , text = 'Lecture' , anchor='w')
        self.tree.heading("a" , text = '1' , anchor='w')
        self.tree.heading("b" , text = '2' , anchor='w')
        self.tree.heading("c" , text = '3' , anchor='w')
        self.tree.heading("d" , text = '4' , anchor='w')
        self.tree.heading("e" , text = '5' , anchor='w')
        self.tree.heading("f" , text = '6' , anchor='w')
        self.tree.heading("g" , text = '7' , anchor='w')
        self.tree.heading("h" , text = '9' , anchor='w')
        self.tree.heading("i" , text = '10' , anchor='w')
        self.tree.heading("j" , text = '11' , anchor='w')
        self.tree.heading("k" , text = '12' , anchor='w')
        self.tree.heading("l" , text = '13' , anchor='w')
        self.tree.heading("m" , text = '14' , anchor='w')
        self.tree.heading("n" , text = '15' , anchor='w')
        self.tree.heading("o" , text = '16' , anchor='w')
        self.tree.heading("p" , text = '17' , anchor='w')
        self.tree.heading("q" , text = '18' , anchor='w')
        self.tree.heading("r" , text = '19' , anchor='w')
        self.tree.heading("s" , text = '20' , anchor='w')
        self.tree.heading("t" , text = '21' , anchor='w')
        self.tree.heading("u" , text = '22' , anchor='w')
        self.tree.heading("v" , text = '23' , anchor='w')
        self.tree.heading("w" , text = '24' , anchor='w')
        self.tree.heading("x" , text = '25' , anchor='w')
        self.tree.heading("y" , text = '26' , anchor='w')
        self.tree.heading("z" , text = '27' , anchor='w')
        self.tree.heading("aa" , text = '28' , anchor='w')
        self.tree.heading("ab" , text = '29' , anchor='w')
        self.tree.heading("ac" , text = '30' , anchor='w')
        self.tree.heading("ad" , text = '31' , anchor='w')

        for i in self.class_columns_page8:
            self.tree.column(i , width=50 , anchor='w')

        self.tree.column('sr' , width=200 , anchor='w')
        self.tree.column('lecture' , width=200 , anchor='w')

        self.show_class()

    ###################################################

    def make_tuples_to_list(self,data):
        newData =  [list(i) for i in data]
        return newData

    def get_lectures_for_report(self,event=None,clear=True):
        pass

    def convert_to_tree(self,list_):
        pass

    def get_details(self,event=None):
        pass

    def get_months_report(self,event=None):
        pass

    def get_rollnumbers_report(self,event=None,clear=True):
        pass

    def show_class(self,event=None):
        pass


if __name__ == "__main__":
    root = ttk.Window('Kanwar Adnan','united')
    app = Report(root,ttk.Frame(root).pack())
    root.focus_set()
    root.mainloop()



__all__ = ['MessageBox','MyFrame','envVars','database','CreateToolTip','Department',
    'Test',
    'Attendance',
    'Report',
    'Session',
    'Session',
    'Staff',
    'Student',
    'Login_Page',
    'Result',
    'SignUp_Page',
    'authenticate'
]

from .tools.messagebox.MessageBox import MessageBox
from .tools.form.Form import MyFrame
from .env import envVars
from .database import database
from .tools.tooltip.ToolTip import CreateToolTip
from .tabs.page2.department.department import Department
from .tabs.page2.result.toplevel.test.test import Test
from .tabs.page1.attendance.attendance import Attendance
from .tabs.page2.report.report import Report
from .tabs.page2.result.result import Result
from .tabs.page2.session.sessions import Session
from .tabs.page2.staff.staff import Staff
from .tabs.page2.student.student import Student
from .tools.login.Login import Login_Page
from .tools.signup.SignUp import SignUp_Page
from .validator import authenticate


# Import Widgets
from tkinter import BOTH , NO , StringVar
import ttkbootstrap as ttk
from kanwar import MessageBox
from kanwar import envVars as myEnv
from kanwar import CreateToolTip

# Import tab
try:
    from test import Test
except:
    from kanwar import Test


class Result:
    def __init__(self,grandMaster,master):
        self.grandMaster = grandMaster
        self.master = master
        self.tests = []
        self.rollnumbers = []
        self.columns = ('sr' ,'testname', 'date' ,'student_name' ,'rollno' ,  'code' , 'lecture' ,'grade', 'total_marks', 'obtained_marks', 'passing_marks','status') 

        self.root = ttk.LabelFrame(self.master , text = 'Results Management')
        self.root.pack(expand=1, fill='both')

        self.left_column = ttk.Frame(self.root)
        self.left_column.pack(side='left',fill='both')

        self.row1 = ttk.Frame(self.left_column)
        self.row1.pack(side = 'top' , fill = 'x',padx=10)

        self.lbl_test = ttk.Label(self.row1 , text = 'Test Code : ')
        self.lbl_test.pack(side = 'left' , padx=[10,26] , pady=10)

        self.com_test = ttk.Combobox(self.row1 , values=() , width=18,state='readonly')
        self.com_test.pack(side='left' , padx=15 , pady =10)

        self.lbl_conf = ttk.Label(self.row1,text='Manage Test : ')
        self.lbl_conf.pack(side='left' , padx=10 , pady=10)

        self.btn_conf = ttk.Button(self.row1 , text ='Configure' , width=18 , style='Outline.TButton' , command=self.addTab)
        self.btn_conf.pack(side = 'left' , padx =5 , pady = 10)

        self.row2 = ttk.Frame(self.left_column)
        self.row2.pack(side = 'top' , fill = 'x',padx=12)

        self.lbl_rollno = ttk.Label(self.row2 , text = "Roll No :" )
        self.lbl_rollno.pack(side = 'left' ,padx=10, pady = 10)

        self.com_rollno_values = ()

        self.com_rollno = ttk.Combobox(self.row2 , width = 18 , values=self.com_rollno_values,state='readonly')
        self.com_rollno.pack(side = 'left' , padx = [45,10] , pady = 10)
        self.com_test.bind("<Enter>",self.get_test_info)

        self.com_rollno.bind("<Enter>",self.get_student_name)

        self.lbl_obtained_marks = ttk.Label(self.row2 , text = "Obtained Marks :" )
        self.lbl_obtained_marks.pack(side = 'left' , padx = [10,0] , pady = 10)

        self.txt_obtained_marks = ttk.Entry(self.row2)
        self.txt_obtained_marks.pack(side = 'left' , padx =5 , pady =10)

        #### Row 2
        self.row3 = ttk.Frame(self.left_column)
        self.row3.pack(expand=1,fill = BOTH,pady=10,padx=10)

        self.scrollx = ttk.Scrollbar(self.row3 , orient='horizontal')
        self.scrolly = ttk.Scrollbar(self.row3 , orient='vertical')
        self.scrolly.pack(side = 'right',fill='y')
        self.scrollx.pack(side = 'bottom',fill='x')

        self.tree = ttk.Treeview(self.row3 , columns=self.columns,
                        xscrollcommand=self.scrollx.set,yscrollcommand=self.scrolly.set)
        self.tree.pack(fill='both',expand=1)

        self.scrollx.config(command=self.tree.xview)
        self.scrolly.config(command=self.tree.yview)

        self.tree.column("#0" , width = 0 , stretch=NO)

        self.tree.heading("sr" , text = 'Sr.' , anchor='w')
        self.tree.heading("student_name" , text = 'Student Name' , anchor='w')
        self.tree.heading("rollno" , text = 'Roll No' , anchor='w')
        self.tree.heading("code" , text = 'Class' , anchor='w')
        self.tree.heading("lecture" , text = 'Subject' , anchor='w')
        self.tree.heading("testname" , text = 'Test Title' , anchor='w')
        self.tree.heading("date" , text = 'Test Date' , anchor='w')
        self.tree.heading("total_marks" , text = 'Total Marks' , anchor='w')
        self.tree.heading("obtained_marks" , text = 'Obtained Marks' , anchor='w')
        self.tree.heading("passing_marks" , text = 'Passing Marks' , anchor='w')
        self.tree.heading("status" , text = 'Status' , anchor='w')
        self.tree.heading("grade" , text = 'Percentage' , anchor='w')

        self.tree.column('sr' , width=200 , anchor='w')
        self.tree.column('student_name' , width=200 , anchor='w')
        self.tree.column('rollno' , width=200 , anchor='w')
        self.tree.column('code' , width=200 , anchor='w')
        self.tree.column('lecture' , width=200 , anchor='w')
        self.tree.column('testname' , width=200 , anchor='w')
        self.tree.column('date' , width=200 , anchor='w')
        self.tree.column('total_marks' , width=200 , anchor='w')
        self.tree.column('obtained_marks' , width=200 , anchor='w')
        self.tree.column('passing_marks' , width=200 , anchor='w')
        self.tree.column('status' , width=200 , anchor='w')
        self.tree.column('grade' , width=200 , anchor='w')

        self.tree.bind("<ButtonRelease-1>",self.getdata_result)
        self.tree["displaycolumns"]=('sr', 'student_name' , 'rollno', 'testname','obtained_marks','status') 

        self.com_test.bind("<<ComboboxSelected>>",self.get_rollnumbers)

        #### Row 3
        ######## BUTTONS 

        self.row4 = ttk.Frame(self.left_column)
        self.row4.pack(fill = 'x' , padx = [0,0] , pady = 10)

        self.btn_add = ttk.Button(self.row4, text = 'Save' , width = 12 , command=self.add_result)
        self.btn_add.pack(side = 'left' , padx = 10)

        self.btn_clear = ttk.Button(self.row4 , text = 'Reset' , width = 12 , command=self.reset_result)
        self.btn_clear.pack(side = 'left' , padx  = 10)

        self.btn_update = ttk.Button(self.row4 , text = 'Update' , width = 12 , command=self.update_result)
        self.btn_update.pack(side = 'left' , padx = 10)

        self.btn_delete = ttk.Button(self.row4 , text = 'Delete' , width = 12 , command=self.delete_result)
        self.btn_delete.pack(side = 'left' , padx = 10)

        self.btn_sort = ttk.Button(self.row4 , text = 'Sort' , width = 12 , command=self.sort_result)
        self.btn_sort.pack(side = 'left' , padx = 10)

        self.btn_export = ttk.Button(self.row4 , text = 'Export' , width = 12 , command=self.export_result)
        self.btn_export.pack(side = 'left' , padx = 10)

        self.txt_search = ttk.Entry(self.row4)
        self.txt_search.pack(side='left',fill='x',expand=1,padx=10)

        self.txt_search.bind("<KeyPress>",self.search_result)
        self.btn_sort.configure(state='disabled')
        self.btn_delete.configure(state='disabled')
        self.btn_update.configure(state='disabled')

        self.show_test()
        self.show_result()

    def addTab(self):
        # is binded with the button configure
        # it will be added when that button will be pressed
        testTab = Test(self.grandMaster,self.root)

    def get_test_info(self,event=None):
        pass

    def get_student_name(self,event=None):
        pass

## come
##############################################################################################
    def show_result(self,event=None):
        pass

    def show_result2(self,event=None):
        pass

    def search_result(self,event=None):
        pass


    def sort_result(self,event=None):
        pass

    ##############################################################################################
    def export_result(self,event=None):
        pass

    ###############################################################################################
    def getdata_result(self,event=None):
        pass

    def reset_result(self,event=None):
        pass

    def reset_result3(self,event=None):
        pass


    def reset_result2(self,event=None):
        pass
    ####################################### FUNCTIONS ##############################################

    def update_result(self,event=None):
        pass


    def delete_result(self,event=None):
        pass

    def add_result(self,event=None):
        pass

    def show_test(self,event=None):
        pass

    def get_rollnumbers(self,event=None,clear=True):
        pass

###################################################################################

if __name__ == "__main__":
    root = ttk.Window('Kanwar Adnan','united')
    app = Result(root,ttk.Frame(root).pack())
    root.mainloop()




FILE_EXPORT_RESULT = 'Results.xlsx'
FILE_EXPORT_CLASS = 'Classes.xlsx'
FILE_EXPORT_STUDENT = 'Students.xlsx'
FILE_EXPORT_USER = 'Users.xlsx'
FILE_EXPORT_TEST = 'Tests.xlsx'

TITLE = 'Kanwar Adnan'

DATABASE = "Database.db"
DATABASEATTENDNACE = "Database2.db"

DEFAULT_ROLE = 'Admin'
DEFAULT_ADMIN = 'admin'
DEFAULT_PASSWORD = '123'
DEFAULT_EMAIL = 'admin'
DEFAULT_CLASS = 'IT-G2'
DEFAULT_LECTURE = 'DLD'

DEFAULT_ROLE_USER = 'Teacher'

LOGGER = 'Admin'

font_lbl=  ['Helvetica',12]

CONNECTION_URL = """mongodb+srv://kanwar:adnan272@cluster0.g2peczr.mongodb.net/?retryWrites=true&w=majority
"""
DATABASE_NAME = "pu"
COLLECTION_NAME = 'results20'

PRODUCTION_CONNECTION_URL = """mongodb+srv://kanwar:adnan272@cluster0.g2peczr.mongodb.net/?retryWrites=true&w=majority
"""
PRODUCTION_DATABASE_NAME = "apps"
PRODUCTION_COLLECTION_NAME = 'myOnlineApps'


from tkinter import ttk,Toplevel,Tk
class CreateToolTip(object):
    """
    create a tooltip for a given widget
    """
    def __init__(self, widget, text='widget info'):
        self.waittime = 500     #miliseconds
        self.wraplength = 512   #pixels
        self.widget = widget
        self.text = text
        self.widget.bind("<Leave>", self.leave)
        self.widget.bind("<ButtonPress>", self.leave)
        self.id = None
        self.tw = None
        self.enter()

    def enter(self, event=None):
        self.schedule()

    def leave(self, event=None):
        self.unschedule()
        self.hidetip()

    def schedule(self):
        self.unschedule()
        if not self.text==None:
            self.id = self.widget.after(self.waittime, self.showtip)

    def unschedule(self):
        id = self.id
        self.id = None
        if id:
            self.widget.after_cancel(id)

    def showtip(self, event=None):
        if not self.widget['state']=='disabled':
            x = y = 0
            x, y, cx, cy = self.widget.bbox("insert")
            x += self.widget.winfo_rootx() + 25
            y += self.widget.winfo_rooty() + 20
            # creates a toplevel window
            self.tw = Toplevel(self.widget)
            # Leaves only the label and removes the app window
            self.tw.wm_overrideredirect(True)
            self.tw.wm_geometry("+%d+%d" % (x, y))
            label = ttk.Label(self.tw,text=self.text, justify='left',
                        wraplength = self.wraplength,font=("Helvetica",12),style='info.TLabel')
            label.pack(ipadx=1)

    def hidetip(self):
        tw = self.tw
        self.tw= None
        if tw:
            tw.destroy()

if __name__=='__main__':
    from tkinter import ttk
    from ttkbootstrap import Style
    style = Style("united")
    root = style.master
    root.title("Kanwar Adnan")
    button = ttk.Button(root , text='Button',style='Outline.TButton')
    button.pack(fill='both' , expand=1)
    CreateToolTip(button , 'Made by Kanwar Adnan (kanwaradnanrajput@gmail.com)')
    root.mainloop()


# Import Widgets
from tkinter import BOTH, NO , StringVar , W , E , S ,N
import ttkbootstrap as ttk
from kanwar import MessageBox
from kanwar import envVars as myEnv

# My Frame
from kanwar import MyFrame

class Attendance:
    def __init__(self,grandMaster,master):
        self.grandMaster = grandMaster
        self.master = master
        self.classes = []
        self.columns = ('Sr','code','lecture','date','students','status') 
        self.obj = object
        self.students_information = []
        self.boxes_infomration = None
        self.took = None
        self.ddate = StringVar()

        self.root = ttk.LabelFrame(self.master , text = 'Attendance Management')
        self.root.pack(expand= 1 , fill =BOTH)

        self.left_column = ttk.Frame(self.root)

        self.left_column.pack(expand=1,fill = BOTH)
        self.root_row1 = ttk.LabelFrame(self.left_column , text='Configure')
        self.root_row1.grid(row = 0 , column = 0 , sticky=W+E , pady = [5,0],padx=10)

        self.lbl_date = ttk.Label(self.root_row1 , text = 'Date : ')
        self.lbl_date.grid(row=0,column=0, padx = [10,0] , pady = 5)

        self.txt_date = ttk.DateEntry(self.root_row1)
        self.txt_date.grid(row=0,column=1, padx = 10 , pady = 10,sticky=W+E)

        self.lbl_class = ttk.Label(self.root_row1 , text = 'Class :')
        self.lbl_class.grid(row=0, padx = 10 , pady = 10,column=2)

        self.com_class = ttk.Combobox(self.root_row1 , state='readonly' , values=self.classes)
        self.com_class.grid(row=0, padx = 10 , pady = 10,sticky=W+E,column=3)

        self.lbl_lecture = ttk.Label(self.root_row1 , text = 'Lecture : ')
        self.lbl_lecture.grid(row=0, padx = 10 , pady = 10,column=4)

        self.com_lecture = ttk.Combobox(self.root_row1 , state='readonly' , values=[]) # lectures
        self.com_lecture.grid(row=0, padx = 10 , pady = 10,sticky=E+W,column=5)

        self.root_row1.columnconfigure(tuple(range(6)), weight=1)

        self.root_row1_1 = ttk.LabelFrame(self.left_column , text='Record : ')
        self.root_row1_1.grid(row = 1 , column = 0 , sticky = W+E)

        self.left_column.columnconfigure(0,weight=1,uniform=1)

        self.lbl_total = ttk.Label(self.root_row1_1 , text='Total Students : ' , font=myEnv.font_lbl)
        self.lbl_total.grid(row = 0 , column=0 , pady=10 , padx = 10 )

        self.lbl_total_val = ttk.Label(self.root_row1_1 , text='#### ' , font=("Helvetica",12,'bold'))
        self.lbl_total_val.grid(row = 0 , column=1 , pady=10 , padx = 10 )

        self.lbl_present = ttk.Label(self.root_row1_1 , text='Present : '  , font=myEnv.font_lbl)
        self.lbl_present.grid(row = 0 , column=2 , pady=10 , padx = 10 )

        self.lbl_present_val = ttk.Label(self.root_row1_1 , text='#### ' , font=("Helvetica",12,'bold'))
        self.lbl_present_val.grid(row = 0 , column=3 , pady=10 , padx = 10 )

        self.lbl_absent = ttk.Label(self.root_row1_1 , text='Absent : ' , font=myEnv.font_lbl)
        self.lbl_absent.grid(row = 0 , column=4 , pady=10 , padx = 10 )

        self.lbl_absent_val = ttk.Label(self.root_row1_1 , text='#### ' , font=("Helvetica",12,'bold'))
        self.lbl_absent_val.grid(row = 0 , column=5 , pady=10 , padx = 10 )

        self.lbl_leave = ttk.Label(self.root_row1_1 , text='Leave : ' , font=myEnv.font_lbl)
        self.lbl_leave.grid(row = 0 , column=6 , pady=10 , padx = 10 )

        self.lbl_leave_val = ttk.Label(self.root_row1_1 , text='#### ' , font=("Helvetica",12,'bold'))
        self.lbl_leave_val.grid(row = 0 , column=7 , pady=10 , padx = 10 )

        self.root_row1_1.columnconfigure(tuple(range(8)),weight=1)

        self.lbls_information = [
            self.lbl_total,
            self.lbl_total_val,
            self.lbl_present,
            self.lbl_present_val,
            self.lbl_absent,
            self.lbl_absent_val,
            self.lbl_leave,
            self.lbl_leave_val,
        ]

        for i in self.lbls_information:
            i.grid_forget()

        self.root_row2 = ttk.LabelFrame(self.left_column , text = 'Attendance : ')
 
        self.root_row3 = ttk.Frame(self.left_column)

        self.root_row_2 = ttk.Frame(self.left_column)
        self.root_row_2.grid(row = 3 , column = 0,pady=[68,10] , sticky = S+N+W+E,padx=10)

        self.root_row_3_3 = ttk.Frame(self.left_column)
        self.root_row_3_3.grid(row = 4 , column = 0 , sticky = W+E,padx=2)

        self.btn_save = ttk.Button(self.root_row_3_3,text='Save' , width=12)
        self.btn_save.pack(side='left',padx=10,pady=10)

        self.btn_reset = ttk.Button(self.root_row_3_3,text='Reset' , width=12 , command = lambda : self.show_class() )
        self.btn_reset.pack(side='left',padx=10,pady=10)

        self.btn_update = ttk.Button(self.root_row_3_3,text='Update' , width=12)
        self.btn_update.pack(side='left',padx=10,pady=10)

        self.btn_delete = ttk.Button(self.root_row_3_3,text='Delete' , width=12)
        self.btn_delete.pack(side='left',padx=10,pady=10)

        self.scrollx = ttk.Scrollbar(self.root_row_2 , orient='horizontal')
        self.scrolly = ttk.Scrollbar(self.root_row_2 , orient='vertical')
        self.scrolly.pack(side = 'right',fill='y')
        self.scrollx.pack(side = 'bottom',fill='x')

        self.tree = ttk.Treeview(self.root_row_2 , columns=self.columns,
                        xscrollcommand=self.scrollx.set,yscrollcommand=self.scrolly.set)
        self.tree.pack(fill=BOTH,expand=1)

        self.scrollx.config(command=self.tree.xview)
        self.scrolly.config(command=self.tree.yview)

        self.tree.column("#0" , width = 0 , stretch=NO)

        self.tree.heading("Sr" , text = 'Sr.' , anchor='w')
        self.tree.heading("code" , text = 'Class' , anchor='w')
        self.tree.heading("lecture" , text = 'Lecture' , anchor='w')
        self.tree.heading("date" , text = 'Date' , anchor='w')
        self.tree.heading("students" , text = 'Students' , anchor='w')
        self.tree.heading("status" , text = 'Status' , anchor='w')

        self.tree.column('Sr' , width= 200 , anchor='w')
        self.tree.column('code' , width= 200 , anchor='w')
        self.tree.column('lecture' , width=200 , anchor='w')
        self.tree.column('date' , width=200 , anchor='w')
        self.tree.column('students' , width=200 , anchor='w')
        self.tree.column('status' , width=200 , anchor='w')

        self.legend = ttk.Label(self.root_row3 , text='' , font=14)
        self.legend.pack(side = 'right' , padx = 10)

        self.btn_save_prime = ttk.Button(self.root_row3 , text = 'Save' , width = 12 , command = self.add_attendance)
        self.btn_save_prime.pack(side = 'left' , padx = 10 , pady = 5)

        self.btn_clear_prime = ttk.Button(self.root_row3 , text = 'Reset' , width = 12 , command = self.reset_page1)
        self.btn_clear_prime.pack(side = 'left' , padx = 10 , pady = 5)

        self.btn_update_prime = ttk.Button(self.root_row3 , text = 'Update' , width = 12 , command = self.update_attendance)
        self.btn_update_prime.pack(side = 'left' , padx = 10 , pady = 5)

        self.btn_delete_prime = ttk.Button(self.root_row3 , text = 'Delete' , width = 12 , command=self.delete_attendance)
        self.btn_delete_prime.pack(side = 'left' , padx = 10 , pady = 5)

        self.btn_save_prime.configure(state='disabled')
        self.btn_delete_prime.configure(state='disabled')

        self.txt_date.bind("<<DateEntrySelected>>", self.record) 
        self.com_class.bind('<<ComboboxSelected>>', lambda e : self.get_lectures(e,clear=True))
        self.com_lecture.bind('<<ComboboxSelected>>', self.record)
        self.tree.bind("<Double-1>",self.recordCsv)
        
        #self.tree.bind("<ButtonRelease-1>",self.recordCsv) # for single click
        self.left_column.rowconfigure((3),weight=1)

        self.get_lectures(clear=True)
        self.get_lectures()
        self.show_attendance()
        self.show_class()


    def show_attendance(self,event=None):
        pass
    #########################################################################################

    def clear_classes(self):
        pass

    def make_tuples_to_list(self,data):
        newData =  [list(i) for i in data]
        return newData

    def add_item(self,data,item):
        pass

    def pop_first(self,data):
        pass

    def get_lectures(self,event=None,clear=True):
        pass

    def get_classes(self,event=None):
        pass

    def get_students(self,event=None):
        pass

    def get_studentsCsv(self,row):
        pass


    def update_attendance(self,event=None):
        pass

    def add_attendance(self,event=None):
        pass

    def reset_page1(self,event=None):
        pass

    def delete_attendance(self,event=None):
        pass

    def record(self,event=None,get=True,*args):
        pass

    def recordCsv(self,event=None,*args):
        pass

    def show_class(self,event=None):
        pass


    ############################################################################

if __name__ == "__main__":
    root = ttk.Window('Kanwar Adnan','united')
    app = Attendance(root,ttk.Frame(root).pack())
    root.focus_set()
    root.mainloop()



from tkinter import ttk , StringVar

class SignUp_Page(ttk.Frame):
    labels = {'name' : 'Name : ' , 'email' : 'Email : ' , 'pass' : 'Password : ' , 'cpass' : 'Confirm : '}
    buttons = {'create' : 'Create' , 'cancel' : 'Cancel'}

    paddings = {'padx' : [10,0] , 'pady' : [20,0]}

    button_width = 10

    button_properties = {'sticky' : 'w'}
    entry_properties = {'sticky' : 'ew'}
    label_properties = {'sticky':'e'}

    entry_properties.update(**paddings)
    button_properties.update(**paddings)
    label_properties.update(**paddings)

    def __init__(self,root, *args,**kwargs):
        self.root = root
        ttk.Frame.__init__(self,self.root,*args,**kwargs)
        self.Name = StringVar()
        self.Email = StringVar()
        self.Pass = StringVar()
        self.CPass = StringVar()
        self.Msg = StringVar()

        self.main_frame = ttk.Frame(self)
        self.main_frame.grid(row = 0 , column=0 , sticky='ew')
        self.main_frame.focus()

        self.lbl_name = ttk.Label(self.main_frame , text = SignUp_Page.labels['name'])
        self.lbl_name.grid(row = 0 , column= 0 , **SignUp_Page.label_properties)

        self.txt_name = ttk.Entry(self.main_frame , textvariable=self.Name)
        self.txt_name.grid(row = 0 , column= 1 , **SignUp_Page.entry_properties)

        self.lbl_email = ttk.Label(self.main_frame , text = SignUp_Page.labels['email'])
        self.lbl_email.grid(row = 0 , column= 2 , **SignUp_Page.label_properties)

        self.txt_email = ttk.Entry(self.main_frame , textvariable=self.Email)
        self.txt_email.grid(row = 0 , column= 3 , **SignUp_Page.entry_properties)

        self.lbl_pass = ttk.Label(self.main_frame , text = SignUp_Page.labels['pass'])
        self.lbl_pass.grid(row = 1 , column= 0 , **SignUp_Page.label_properties)

        self.txt_pass = ttk.Entry(self.main_frame , textvariable=self.Pass)
        self.txt_pass.grid(row = 1 , column= 1 , **SignUp_Page.entry_properties)

        self.lbl_cpass = ttk.Label(self.main_frame , text = SignUp_Page.labels['cpass'])
        self.lbl_cpass.grid(row = 1 , column= 2 , **SignUp_Page.label_properties)

        self.txt_cpass = ttk.Entry(self.main_frame , textvariable=self.CPass)
        self.txt_cpass.grid(row = 1 , column= 3 , **SignUp_Page.entry_properties)

        self.lbl_message = ttk.Label(self.main_frame, textvariable=self.Msg,style='danger.TLabel')
        self.lbl_message.grid(row=2,column=1,columnspan=3 , **SignUp_Page.paddings,sticky='w')

        self.bottom_frame = ttk.Frame(self)
        self.bottom_frame.grid(row = 1 , column=0 , sticky='ew')

        self.btn_create = ttk.Button(self.bottom_frame , text = SignUp_Page.buttons['create'] , width=SignUp_Page.button_width)
        self.btn_create.pack(side='left',padx = [130,0] , pady = [40,0])

        self.btn_cancel = ttk.Button(self.bottom_frame , text = SignUp_Page.buttons['cancel'],style='primary.Outline.TButton' , width=SignUp_Page.button_width)
        self.btn_cancel.pack(side='left',padx = [10] , pady = [40,0])
        self.btn_cancel.configure(command=lambda : self.root.destroy())

        self.bottom_frame.columnconfigure((0,1),weight=1)

        self.main_frame.columnconfigure((0,1,2,3),weight=1)

        self.columnconfigure(0,weight=1)

if __name__ == '__main__':
     # IMPORT MODERN TTK LIB
    from ttkbootstrap import Style

    # MAKING IT'S OBJECT SETTINGS
    style = Style('united')

    # MAKING ROOT OBJECT    
    root = style.master
    root.title("Kanwar Adnan")
    root.geometry("660x240+100+100")
    root.resizable(False,False) 

    # MAKING LOGIN PAGE
    page_signin_object = SignUp_Page(root)
    page_signin_object.pack(expand=1,fill='both',padx=10,pady=10)
    page_signin_object.txt_pass.configure(show='*')
    
    root.mainloop()



# Import Widgets
from tkinter import BOTH , NO , StringVar , Toplevel
import ttkbootstrap as ttk
from kanwar import MessageBox
from kanwar import envVars as myEnv
from kanwar import Department

class Test:
    def __init__(self,grandMaster,master):
        self.grandMaster = grandMaster
        self.master = master
        #####################
        #VARS
        self.dcourse = StringVar()
        self.dcourse_code = StringVar()
        self.dlecture = StringVar()
        self.dname_test = StringVar()
        self.dtotal_marks_test = StringVar()
        self.dpassing_marks_test = StringVar()
        self.dname_test_desc = StringVar()
        self.ddate_test = StringVar()
        #####################
        self.classes = [] 
        self.lectures= []
        self.tests = []

        self.makeGUI()
        self.show_class()
        self.show_test()

        self.root.bind("<Return>",self.add_test)
        self.root.bind("<Control-u>",self.update_test)
        self.root.bind("<Control-d>",self.delete_test)
        self.root.bind("<Control-r>",self.reset_test)
        self.root.bind("<Control-s>",self.export_test)
        self.root.bind("<Control-f>",lambda e  : self.txt_search_test.focus_set())

        self.root.protocol("WM_DELETE_WINDOW", self.quit_me)
        self.root.wait_window()


    def quit_me(self,e=None):
        op = MessageBox('Confirm',"Do you really wish to close this tab?",b1='Yes',b2='No')
        if op.choice=='Yes':
            self.root.destroy()

    def setClassTab(self,classTab):
        self.classTab = classTab

    def makeGUI(self,event=None):
        self.root = Toplevel(self.grandMaster)
        self.root.minsize(940,600)

        self.root.geometry("940x600+50+80")
        self.root.focus()

        self.main_frame  = ttk.LabelFrame(self.root , text='Test Configurations')
        self.main_frame.pack(expand=1,fill='both' , padx = 10 , pady = 10)

        self.first_frame = ttk.Frame(self.main_frame)
        self.first_frame.pack(side='top',fill='x')

        self.lbl_test_name = ttk.Label(self.first_frame , text= 'Test Name :')
        self.lbl_test_name.grid(row=0 , column = 0 , padx=10 , pady=10)

        self.txt_test_name = ttk.Entry(self.first_frame , textvariable=self.dname_test)
        self.txt_test_name.grid(row=0 , column = 1 , padx=10 , pady=10 , sticky='ew')

        self.lbl_test_name_desc = ttk.Label(self.first_frame , text= 'Description :')
        self.lbl_test_name_desc.grid(row=0 , column = 2 , padx=10 , pady=10)

        self.txt_test_name_desc = ttk.Entry(self.first_frame , textvariable=self.dname_test_desc)
        self.txt_test_name_desc.grid(row=0 , column = 3 , padx=10 , pady=10 , sticky='ew',columnspan=3)

        self.lbl_date = ttk.Label(self.first_frame , text= 'Date :')
        self.lbl_date.grid(row=1 , column = 0 , padx=10 , pady=10)


        self.ent_date = ttk.DateEntry(self.first_frame , width=18)
        self.ent_date.grid(row=1 , column = 1 , padx=10 , pady=10 , sticky='ew')

        self.lbl_class = ttk.Label(self.first_frame, text='Class Code  :   ')
        self.lbl_class.grid(row=1 , column = 2 , padx=10 , pady=10)

        self.com_class_test = ttk.Combobox(self.first_frame , values=self.classes, width=18,state='readonly')
        self.com_class_test.grid(row=1 , column = 3 , padx=10 , pady=10 , sticky='ew')

        self.lbl_lecture = ttk.Label(self.first_frame, text='Lecture : ')
        self.lbl_lecture.grid(row=1 , column = 4 , padx=10 , pady=10)

        self.com_lecture_test = ttk.Combobox(self.first_frame , values=self.lectures, width=18,state='readonly')
        self.com_lecture_test.grid(row=1 , column = 5 , padx=10 , pady=10 , sticky='ew')

        self.com_class_test.bind("<<ComboboxSelected>>",self.get_lectures_for_test)

        self.lbl_total_marks = ttk.Label(self.first_frame,text='Total Marks : ')
        self.lbl_total_marks.grid(row=2 , column = 0 , padx=10 , pady=10)

        self.txt_total_marks = ttk.Entry(self.first_frame , textvariable=self.dtotal_marks_test)
        self.txt_total_marks.grid(row=2 , column = 1 , padx=10 , pady=10 , sticky='ew')

        self.lbl_passing_marks = ttk.Label(self.first_frame,text='Passing Marks : ')
        self.lbl_passing_marks.grid(row=2 , column = 2 , padx=10 , pady=10)

        self.txt_passing_marks = ttk.Entry(self.first_frame,textvariable=self.dpassing_marks_test)
        self.txt_passing_marks.grid(row=2 , column = 3 , padx=10 , pady=10 , sticky='ew')

        self.first_frame.columnconfigure((0,1,2,3,4,5) , weight=1)

        self.second_frame = ttk.Frame(self.main_frame)
        self.second_frame.pack(expand=1,fill='both')

        #### Row 1

        self.scrollx_test = ttk.Scrollbar(self.second_frame , orient='horizontal')
        self.scrolly_test = ttk.Scrollbar(self.second_frame , orient='vertical')
        self.scrolly_test.pack(side = 'right',fill='y')
        self.scrollx_test.pack(side = 'bottom',fill='x')

        self.class_columns_test = ('sr','test','test_desc' , 'code','subject','date','total_marks','passing_marks') 

        self.tree = ttk.Treeview(self.second_frame , columns=self.class_columns_test,
                        xscrollcommand=self.scrollx_test.set,yscrollcommand=self.scrolly_test.set)
        self.tree.pack(fill=BOTH,expand=1)

        self.scrollx_test.config(command=self.tree.xview)
        self.scrolly_test.config(command=self.tree.yview)

        self.tree.column("#0" , width = 0 , stretch=NO)

        self.tree.heading("sr" , text = 'Sr.' , anchor='w')
        self.tree.heading("test" , text = 'Test Title' , anchor='w')
        self.tree.heading("test_desc" , text = 'Test' , anchor='w')
        self.tree.heading("code" , text = 'Class' , anchor='w')
        self.tree.heading("subject" , text = 'Lecture' , anchor='w')
        self.tree.heading("date" , text = 'Date' , anchor='w')
        self.tree.heading("total_marks" , text = 'Total Marks' , anchor='w')
        self.tree.heading("passing_marks" , text = 'Passing Marks' , anchor='w')

        self.tree.column('sr' , width=200 , anchor='w')
        self.tree.column('test' , width=200 , anchor='w')
        self.tree.column('test_desc' , width=200 , anchor='w')
        self.tree.column('code' , width=200 , anchor='w')
        self.tree.column('subject' , width=200 , anchor='w')
        self.tree.column('date' , width=200 , anchor='w')
        self.tree.column('total_marks' , width=200 , anchor='w')
        self.tree.column('passing_marks' , width=200 , anchor='w')

        #### Row 3
        ######## BUTTONS 
        self.third_frame = ttk.Frame(self.main_frame)
        self.third_frame.pack(fill = 'x' , padx = [0,0] , pady = [10,10])

        self.btn_add_test = ttk.Button(self.third_frame, text = 'Save' , width = 12,command=self.add_test)
        self.btn_add_test.pack(side = 'left' , padx = 10)

        self.btn_clear_test = ttk.Button(self.third_frame , text = 'Reset' , width = 12,command=self.reset_test)
        self.btn_clear_test.pack(side = 'left' , padx  = 10)

        self.btn_update_test = ttk.Button(self.third_frame , text = 'Update' , width = 12,command=self.update_test)
        self.btn_update_test.pack(side = 'left' , padx = 10)

        self.btn_delete_test = ttk.Button(self.third_frame , text = 'Delete' , width = 12,command=self.delete_test)
        self.btn_delete_test.pack(side = 'left' , padx = 10)

        self.btn_sort_test = ttk.Button(self.third_frame , text = 'Sort' , width = 12,state='disabled')
        self.btn_sort_test.pack(side = 'left' , padx = 10)

        self.btn_export_test = ttk.Button(self.third_frame , text = 'Export' , width = 12,command=self.export_test)
        self.btn_export_test.pack(side = 'left' , padx = 10)

        self.txt_search_test = ttk.Entry(self.third_frame)
        self.txt_search_test.pack(side='left',padx=10,pady=10,fill='x',expand=1)

        self.txt_search_test.bind("<KeyPress>",self.search_test)

        self.btn_update_test.configure(state='disabled')
        self.btn_delete_test.configure(state='disabled')
        self.get_lectures_for_test()
        self.tree.bind("<ButtonRelease-1>",self.getdata_test)

        ###############################################################################

    def make_tuples_to_list(self,data):
        newData =  [list(i) for i in data]
        return newData

    def get_lectures_for_test(self,event=None):
        pass

    def show_test(self,event=None):
        pass

    def search_test(self,event=None):
        pass


    def export_test(self,event=None):
        pass

    ###############################################################################################
    def getdata_test(self,event=None):
        pass

    def reset_test(self,event=None):
        pass

    ####################################### FUNCTIONS ##############################################
    def update_data(self,event=None):
        pass

    def update_test(self,event=None):
        pass

    def delete_test(self,event=None):
        pass

    def add_test(self,event=None):
        pass

    def show_class(self,event=None):
        pass


    ###############################################################################

if __name__ == "__main__":
    root = ttk.Window('Kanwar Adnan','united')
    frame = Frame(root)
    frame.pack()
    testTab = Test(root,frame)
    #testTab.setClassTab(classTab)
    root.mainloop()




# Import Widgets
from tkinter import BOTH , NO , StringVar
import ttkbootstrap as ttk
from kanwar import MessageBox
from kanwar import envVars as myEnv

class Department:
    def __init__(self,grandMaster,master):
        self.grandMaster = grandMaster
        self.master = master
        self.classes = [] 
        self.dcourse = StringVar()
        self.dcourse_code = StringVar()
        self.dlecture = StringVar()

        self.root = ttk.LabelFrame(self.master , text = 'Class Management')
        self.root.pack(fill = BOTH, expand=1)

        self.left_column = ttk.Frame(self.root)
        self.left_column.pack(expand=1,fill = BOTH)

        #### Row 1

        self.row1 = ttk.Frame(self.left_column)
        self.row1.pack(side = 'top' , fill = 'x', padx = 10 , pady = 10)

        self.lbl_course_code = ttk.Label(self.row1 , text = 'Class Code :   ')
        self.lbl_course_code.pack(side = 'left' , padx = 10)

        self.txt_course_code = ttk.Entry(self.row1 , textvariable=self.dcourse_code)
        self.txt_course_code.pack(side='left' , padx = 18)

        self.lbl_course = ttk.Label(self.row1 , text = 'Description : ')
        self.lbl_course.pack(side = 'left' , padx = 10)

        self.txt_course = ttk.Entry(self.row1 , textvariable=self.dcourse)
        self.txt_course.pack(side = 'left' , padx = 10,fill='x',expand=1)

        self.row2 = ttk.Frame(self.left_column)
        self.row2.pack(side = 'top' , fill = 'x', padx = 10 , pady = 10)

        self.lbl_lecture = ttk.Label(self.row2 , text = 'Lectures : ')
        self.lbl_lecture.pack(side = 'left' , padx = 10)

        self.txt_lecture = ttk.Entry(self.row2 , textvariable=self.dlecture , width = 45)
        self.txt_lecture.pack(side = 'left',fill='x',padx=[35,10],expand=1)

        #### Row 3

        self.row3 = ttk.Frame(self.left_column)
        self.row3.pack(fill = 'both' , padx = 10 , pady = 10, expand=1)

        self.scrollx = ttk.Scrollbar(self.row3 , orient='horizontal')
        self.scrolly = ttk.Scrollbar(self.row3 , orient='vertical')
        self.scrolly.pack(side = 'right',fill='y')
        self.scrollx.pack(side = 'bottom',fill='x')

        self.class_columns = ('Sr','Class','Code','lecture') 

        self.tree = ttk.Treeview(self.row3 , columns=self.class_columns,
                        xscrollcommand=self.scrollx.set,yscrollcommand=self.scrolly.set)
        self.tree.pack(fill=BOTH,expand=1)

        self.scrollx.config(command=self.tree.xview)
        self.scrolly.config(command=self.tree.yview)

        self.tree.column("#0" , width = 0 , stretch=NO)

        self.tree.heading("Sr" , text = 'Sr.' , anchor='w')
        self.tree.heading("Class" , text = 'Code' , anchor='w')
        self.tree.heading("Code" , text = 'Description' , anchor='w')
        self.tree.heading("lecture" , text = 'Lectures' , anchor='w')

        self.tree.column('Sr' , width= 200 , anchor='w')
        self.tree.column('Class' , width= 200 , anchor='w')
        self.tree.column('Code' , width= 200 , anchor='w')
        self.tree.column('lecture' , width=200 , anchor='w')

        #### Row 3
        ######## BUTTONS 
        self.row4 = ttk.Frame(self.left_column)
        self.row4.pack(fill = 'both' , padx = [0,0] , pady = 10)

        self.btn_add = ttk.Button(self.row4, text = 'Save' , width = 12 , command=self.add_class)
        self.btn_add.pack(side = 'left' , padx = 10)

        self.btn_clear = ttk.Button(self.row4 , text = 'Reset' , width = 12 , command=self.reset_class)
        self.btn_clear.pack(side = 'left' , padx  = 10)

        self.btn_update = ttk.Button(self.row4 , text = 'Update' , width = 12 , command=self.update_class)
        self.btn_update.pack(side = 'left' , padx = 10)

        self.btn_delete = ttk.Button(self.row4 , text = 'Delete' , width = 12 , command=self.delete_class)
        self.btn_delete.pack(side = 'left' , padx = 10)

        self.btn_sort = ttk.Button(self.row4 , text = 'Sort' , width = 12 , state='disabled')
        self.btn_sort.pack(side = 'left' , padx = 10)

        self.btn_export = ttk.Button(self.row4 , text = 'Export' , width = 12 , command=self.export_class)
        self.btn_export.pack(side = 'left' , padx = 10)

        self.txt_search = ttk.Entry(self.row4)
        self.txt_search.pack(side='left',fill='x',expand=1,padx=10)

        self.txt_search.bind("<KeyPress>",self.search_class)

        self.btn_update.configure(state='disabled')
        self.btn_delete.configure(state='disabled')
        self.tree.bind("<ButtonRelease-1>",self.getData)
        self.show_class()

        ####################################### DATA BASE START ##########################################
    def getClasses(self):
        return self.classes

    def show_class(self,event=None):
        pass

    def search_class(self,event=None):
        pass


    def export_class(self,event=None):
        pass

    ###############################################################################################            
    def reset_class(self,event=None):
        pass

    def getData(self,event=None):
        pass

    ####################################### FUNCTIONS ##############################################

    def delete_class(self,event=None):
        pass

    def update_class(self,event=None):
        pass

    def add_class(self,event=None):
        pass
        ####################################### DATA BASE END ##########################################

if __name__ == "__main__":
    root = ttk.Window('Kanwar Adnan','united')
    app = Department(root,ttk.Frame(root).pack())
    root.focus_set()
    root.mainloop()



# Import Widgets
import ttkbootstrap as ttk
from tkinter import BOTH , StringVar , NO
from kanwar import MessageBox
from kanwar import envVars as myEnv

class Staff:
    def __init__(self,grandMaster,master):
        self.grandMaster = grandMaster
        self.master = master
        self.classes = [] 
        self.lectures = []
        self.root = ttk.LabelFrame(self.master , text = 'Staff Management')
        self.root.pack(fill = BOTH, expand=1)

        self.dteacher_name = StringVar()
        self.demail = StringVar()
        self.dpassword = StringVar()

        self.left_column_page5 = ttk.Frame(self.root)
        self.left_column_page5.pack(expand=1,fill = BOTH)

        #### Row 1
        self.left_column_page5_row1 = ttk.Frame(self.left_column_page5)
        self.left_column_page5_row1.pack(side = 'top' , fill = 'x', padx = 10)

        self.lbl_class_page5 = ttk.Label(self.left_column_page5_row1 , text='Class Code :   ')
        self.lbl_class_page5.grid(row=0,column=0,pady=10)

        self.com_class_page5 = ttk.Combobox(self.left_column_page5_row1 , state='readonly',values=self.classes , width=23)
        self.com_class_page5.grid(row=0,column=1,pady=10)

        self.lbl_lecture_page5 = ttk.Label(self.left_column_page5_row1, text='Lecture : ')
        self.lbl_lecture_page5.grid(row=0,column=2,pady=10)

        self.com_lecture_page5 = ttk.Combobox(self.left_column_page5_row1 , state='readonly' , values=self.lectures, width = 23)
        self.com_lecture_page5.grid(row=0,column=3,pady=10)

        self.lbl_role = ttk.Label(self.left_column_page5_row1 , text = 'Role : ')
        self.lbl_role.grid(row=0,column=4)

        self.com_roles = ('Admin','Teacher','Assistant')

        self.com_role = ttk.Combobox(self.left_column_page5_row1 , state='readonly',values=self.com_roles , width = 23)
        self.com_role.grid(row=0,column=5)

        self.com_class_page5.bind('<<ComboboxSelected>>', lambda e :self.get_lectures_for_staff(e))

        self.lbl_teacher_name = ttk.Label(self.left_column_page5_row1 , text = 'Teacher Name : ')
        self.lbl_teacher_name.grid(row=1,column=0,pady=10)

        self.txt_teacher_name = ttk.Entry(self.left_column_page5_row1 , width = 25 , textvariable=self.dteacher_name)
        self.txt_teacher_name.grid(row=1,column=1,pady=10)

        self.lbl_email = ttk.Label(self.left_column_page5_row1 , text = 'Email Address : ')
        self.lbl_email.grid(row=1,column=2,pady=10)

        self.txt_email = ttk.Entry(self.left_column_page5_row1 , width = 25 , textvariable=self.demail)
        self.txt_email.grid(row=1,column=3,pady=10)

        self.lbl_password = ttk.Label(self.left_column_page5_row1 , text = 'Password : ')
        self.lbl_password.grid(row=1,column=4,pady=10)

        self.txt_password = ttk.Entry(self.left_column_page5_row1 , width = 25 , textvariable=self.dpassword)
        self.txt_password.grid(row=1,column=5,pady=10)

        self.left_column_page5_row1.columnconfigure((0,1,2,3,4,5),weight=1)

        self.left_column_page5_row2 = ttk.Frame(self.left_column_page5)
        self.left_column_page5_row2.pack(fill = 'both' , padx = 10 , pady = [10,20], expand=1)

        self.scrollx_page5 = ttk.Scrollbar(self.left_column_page5_row2 , orient='horizontal')
        self.scrolly_page5 = ttk.Scrollbar(self.left_column_page5_row2 , orient='vertical')
        self.scrolly_page5.pack(side = 'right',fill='y')
        self.scrollx_page5.pack(side = 'bottom',fill='x')

        self.class_columns_page5 = ('Sr','name','role','code','lecture','email','pass') 

        self.tree = ttk.Treeview(self.left_column_page5_row2 , columns=self.class_columns_page5,
                        xscrollcommand=self.scrollx_page5.set,yscrollcommand=self.scrolly_page5.set)
        self.tree.pack(fill=BOTH,expand=1)

        self.scrollx_page5.config(command=self.tree.xview)
        self.scrolly_page5.config(command=self.tree.yview)

        self.tree.column("#0" , width = 0 , stretch=NO)

        self.tree.heading("Sr" , text = 'Sr.' , anchor='w')
        self.tree.heading("name" , text = 'Name' , anchor='w')
        self.tree.heading("role" , text = 'Role' , anchor='w')
        self.tree.heading("code" , text = 'Class',anchor='w')
        self.tree.heading("lecture" , text = 'Lecture' , anchor='w')
        self.tree.heading("email" , text = 'Email' , anchor='w')
        self.tree.heading("pass" , text = 'Password' , anchor='w')

        self.tree.column('Sr' , width=200 , anchor='w')
        self.tree.column('code' , width=200 , anchor='w')
        self.tree.column('lecture' , width=200 , anchor='w')
        self.tree.column('name' , width=200 , anchor='w')
        self.tree.column('role' , width=200 , anchor='w')
        self.tree.column('email' , width=200 , anchor='w')
        self.tree.column('pass' , width=200 , anchor='w')

        self.tree["displaycolumns"]=('Sr', 'code' , 'lecture' , 'name' , 'role' , 'email')

        #### Row 3
        ######## BUTTONS 

        self.left_column_page5_row3 = ttk.Frame(self.left_column_page5)
        self.left_column_page5_row3.pack(fill = 'x' , padx = [0,0] , pady = [0,10])

        self.btn_add_page5 = ttk.Button(self.left_column_page5_row3, text = 'Save' , width = 12 , command=self.add_user)
        self.btn_add_page5.pack(side = 'left' , padx = 10)

        self.btn_clear_page5 = ttk.Button(self.left_column_page5_row3 , text = 'Reset' , width = 12 , command=self.reset_user)
        self.btn_clear_page5.pack(side = 'left' , padx  = 10)

        self.btn_update_page5 = ttk.Button(self.left_column_page5_row3 , text = 'Update' , width = 12 , command=self.update_user)
        self.btn_update_page5.pack(side = 'left' , padx = 10)

        self.btn_delete_page5 = ttk.Button(self.left_column_page5_row3 , text = 'Delete' , width = 12 , command=self.delete_user)
        self.btn_delete_page5.pack(side = 'left' , padx = 10)

        self.btn_sort_page5 = ttk.Button(self.left_column_page5_row3 , text = 'Sort' , width = 12 , command=self.sort_user)
        self.btn_sort_page5.pack(side = 'left' , padx  = 10)

        self.btn_export_page5 = ttk.Button(self.left_column_page5_row3 , text = 'Export' , width = 12 , command=self.export_user)
        self.btn_export_page5.pack(side = 'left' , padx  = 10)

        self.txt_search_page5= ttk.Entry(self.left_column_page5_row3)
        self.txt_search_page5.pack(side='left',padx=10,fill='x',expand=1)

        self.txt_search_page5.bind('<KeyPress>',self.search_user)
        self.btn_update_page5.configure(state='disabled')
        self.btn_delete_page5.configure(state='disabled')
        self.btn_sort_page5.configure(state='disabled')

        self.tree.bind("<ButtonRelease-1>",self.getdata_user)
        self.show_class()
        self.show_user()
    ###############################################################################################

    def make_tuples_to_list(self,data):
        newData =  [list(i) for i in data]
        return newData

    def get_lectures_for_staff(self,event=None):
        pass

    def show_user(self,event=None):
        pass

    def show_user2(self,event=None):
        pass

    def sort_user(self,event=None):
        pass

    def export_user(self,event=None):
        pass

    def getdata_user(self,event=None):
        pass

    def reset_user(self,event=None):
        pass

    def reset_user2(self,event=None):
        pass

    def search_user(self,event=None):
        pass

    ####################################### FUNCTIONS ##############################################
    ###############################################################################

    def delete_user(self,event=None):
        pass

    def update_user(self,event=None):
        pass

    def add_user(self,event=None):
        pass

    def show_class(self,event=None):
        pass


    ###############################################################################

if __name__ == "__main__":
    root = ttk.Window('Kanwar Adnan','united')
    root.focus_set()
    app = Staff(root,ttk.Frame(root).pack())
    root.mainloop()




from tkinter import ttk , StringVar, BooleanVar


class Login_Page(ttk.Frame):

    labels = {'id' : 'Email : ','pass':'Password : '}
    buttons = {'signin' : 'Login' , 'signup' : 'Sign Up'}
    paddings = {'padx' : [10,0] , 'pady' : [20,0]}

    button_width = 10
    button_properties = {'sticky' : 'w'}
    entry_properties = {'sticky' : 'ew'}
    label_properties = {'sticky' : 'e'}

    entry_properties.update(**paddings)
    button_properties.update(**paddings)
    label_properties.update(**paddings)

    def __init__(self,root, *args,**kwargs):
        self.root = root
        ttk.Frame.__init__(self,self.root,*args,**kwargs)
        self.Pass = StringVar()
        self.Id = StringVar()
        self.Msg = StringVar()
        self.Keep_login = BooleanVar()

        self.main_frame = ttk.Frame(self)
        self.main_frame.grid(row = 0 , column=0 , sticky='ew')
        self.main_frame.focus()

        self.lbl_id = ttk.Label(self.main_frame, text = Login_Page.labels['id'])
        self.lbl_id.grid(row=0,column=0,**Login_Page.label_properties)

        self.txt_id = ttk.Entry(self.main_frame,textvariable=self.Id)
        self.txt_id.grid(row=0,column=1,**Login_Page.entry_properties)

        self.lbl_pass = ttk.Label(self.main_frame, text = Login_Page.labels['pass'])
        self.lbl_pass.grid(row=1,column=0,**Login_Page.label_properties)

        self.txt_pass = ttk.Entry(self.main_frame,textvariable=self.Pass)
        self.txt_pass.grid(row=1,column=1,**Login_Page.entry_properties)

        self.chk_keep_login = ttk.Checkbutton(self.main_frame, text='Keep me Logged in' , variable=self.Keep_login)
        self.chk_keep_login.grid(row=2,column=1,sticky='w',**Login_Page.paddings)

        self.lbl_message = ttk.Label(self.main_frame, textvariable=self.Msg,style='danger.TLabel')
        self.lbl_message.grid(row=2,column=0,columnspan=3,sticky='e' , **Login_Page.paddings)

        self.bottom_frame = ttk.Frame(self)
        self.bottom_frame.grid(row = 1 , column=0)

        self.btn_sign_in = ttk.Button(self.bottom_frame , text = Login_Page.buttons['signin'] , width=Login_Page.button_width)
        self.btn_sign_in.grid(row = 0 , column = 1,**Login_Page.button_properties)

        self.btn_sign_up = ttk.Button(self.bottom_frame , text = Login_Page.buttons['signup'],style='primary.Outline.TButton' , width=Login_Page.button_width)
        self.btn_sign_up.grid(row = 0 , column = 2,**Login_Page.button_properties)

        self.main_frame.columnconfigure((0,1,2),weight=1)
        self.bottom_frame.columnconfigure((0,1,2),weight=1)

        self.columnconfigure(0,weight=1)

if __name__ == '__main__':
     # IMPORT MODERN TTK LIB
    from ttkbootstrap import Style

    # MAKING IT'S OBJECT SETTINGS
    style = Style('united')

    # MAKING ROOT OBJECT    
    root = style.master
    root.title("Kanwar Adnan")
    root.geometry("660x240+100+100")
    root.resizable(False,False) 

    # MAKING LOGIN PAGE
    page_login_object = Login_Page(root)
    page_login_object.pack(expand=1,fill='both',padx=10,pady=10)
    page_login_object.txt_pass.configure(show='*')
    
    root.mainloop()



from tkinter import ttk,Toplevel

class MessageBox:

    def __init__(self,title='MessageBox', msg='Hello I will be your message',parent='', b1='Ok', b2='',b3=''):
        self.title = title
        self.msg = msg
        self.choice = None
        self.b1 = b1
        self.b2 = b2
        self.b3 = b3
        self.parent = parent

        self.root = Toplevel()
        self.root.focus()
        self.root.title(self.title)
        self.root.resizable(False,False)

        self.root.update_idletasks()
        width = self.root.winfo_width()
        frm_width = self.root.winfo_rootx() - self.root.winfo_x()
        win_width = width + 2 * frm_width
        height = self.root.winfo_height()
        titlebar_height = self.root.winfo_rooty() - self.root.winfo_y()
        win_height = height + titlebar_height + frm_width
        x = self.root.winfo_screenwidth() // 2 - win_width // 2
        y = self.root.winfo_screenheight() // 2 - win_height // 2
        self.root.geometry('+{}+{}'.format(x, y))

        self.main_frame= ttk.Frame(self.root)
        self.main_frame.pack(fill='both',expand=1)

        self.message_frame= ttk.Frame(self.main_frame)
        self.message_frame.pack(side='top',fill='both',expand=1,pady=15, padx = 10)

        self.lbl_message = ttk.Label(self.message_frame , text=self.msg , wraplength=128*3 , font=("Helvetica",12))
        self.lbl_message.pack(side = 'left' , padx = 5 , pady = 1)

        self.footer_frame= ttk.Frame(self.main_frame)
        self.footer_frame.pack(side='bottom',fill='x',expand=1)

        self.button_1 = ttk.Button(self.footer_frame , text = self.b1 , default='active')
        self.button_1.pack(side = 'right' , padx = 5 , pady = 5)
        self.button_1.configure(command=self.click1)
        self.button_1.focus()

        if self.b2:

            self.button_2 = ttk.Button(self.footer_frame , text = self.b2, style='primary.Outline.TButton')
            self.button_2.pack(side = 'right' , padx = 5 , pady = 5)
            self.button_2.configure(command=self.click2)

        if self.b3:

            self.button_2 = ttk.Button(self.footer_frame , text = self.b3, style='primary.Outline.TButton')
            self.button_2.pack(side = 'right' , padx = 5 , pady = 5)
            self.button_2.configure(command=self.click3)

        self.button_1.bind("<Return>",lambda e: self.click1())
        self.root.bind("<Escape>",lambda e: self.root.destroy())

        #self.root.after(5000,lambda : self.root.destroy()) # UNCOMMENT IT IF YOU WANT AUTOMATIC DESTROY MESSAGE BOXES
        self.root.wait_window()

    def closed(self):
        self.root.destroy()
        self.choice='closed'
        
    def click1(self,event=None):
        self.root.destroy()
        self.choice=self.b1

    def click2(self,event=None):
        self.root.destroy()
        self.choice=self.b2

    def click3(self,event=None):
        self.root.destroy()
        self.choice=self.b3

if __name__ == '__main__':
     # IMPORT MODERN TTK LIB
    from ttkbootstrap import Style

    # MAKING IT'S OBJECT SETTINGS
    style = Style('united')

    # MAKING ROOT OBJECT    
    root = style.master
    root.withdraw()
    root.title("Kanwar Adnan")
    MessageBox("Information","Hello It's Kanwar Adnan (kanwaradnanrajput@gmail.com)",b2='Close')


from kanwar import MessageBox
from kanwar import Login_Page
from kanwar import SignUp_Page
from tkinter import Toplevel , BOTH
from time import strftime

DATABASE = "Database.db"
DATABASEATTENDNACE = "Database2.db"

DEFAULT_ROLE = 'Admin'
DEFAULT_ADMIN = 'admin'
DEFAULT_PASSWORD = '123'
DEFAULT_EMAIL = 'admin'
DEFAULT_CLASS = 'IT-G2'
DEFAULT_LECTURE = 'DLD'

DEFAULT_ROLE_USER = 'Teacher'

LOGGER = 'Admin'

def Login_System(root,nb):
    root.withdraw()

    page_login = Toplevel(root)
    page_login.geometry("660x200+200+200")
    page_login.resizable(False,False)

    page_login_object = Login_Page(page_login)
    page_login_object.pack(expand=1,fill='both')
    page_login_object.txt_pass.configure(show="*")

    def Sign_up_page(event=None):
        page_login.withdraw()

        page_signup = Toplevel(page_login)
        page_signup.focus()
        page_signup.geometry("660x240+200+200")
        page_signup.resizable(False,False)

        page_signup_object = SignUp_Page(page_signup)
        page_signup_object.pack(expand=1,fill='both',padx= 10 , pady =10)
        page_signup_object.txt_name.focus()

        page_signup_object.txt_pass.configure(show="*")
        page_signup_object.txt_cpass.configure(show="*")
        def create_account():
            pass
        page_signup_object.btn_create.configure(command=create_account)
        def del_window(event=None):
            page_login.deiconify()
            page_signup.destroy()
        page_signup.protocol("WM_DELETE_WINDOW",del_window)
        page_signup.wait_window()

    def confirm_login(event=None):
        pass
    # ASSIGNING CUSTOM FUNCTIONS TO BUTTONS
    page_login_object.btn_sign_up.configure(command=Sign_up_page)
    page_login_object.btn_sign_in.configure(command=confirm_login)

    # LAST THING TO BIND
    page_login.protocol("WM_DELETE_WINDOW",lambda : root.destroy())
    page_login.after(100,lambda : page_login.focus_set())
    page_login.wait_window()
    return LOGGER

def check_previous_Login(root,nb):
    pass
def redirect(user,password,root,nb):
    pass

if __name__ == '__main__':
     # IMPORT MODERN TTK LIB
    from ttkbootstrap import Style

    # MAKING IT'S OBJECT SETTINGS
    style = Style('united')

    # MAKING ROOT OBJECT    
    root = style.master
    root.withdraw()
    root.title("Kanwar Adnan")
    MessageBox("Information","Authentication system of Kanwar Adnan (Kanwaradnanrajput@gmail.com)",b2='Close')